@@ -837,12 +837,12 @@ sv_res_table <- function(fit_res, format_out = FALSE) {
 #' 'options(fsl.path = "/path/to/fsl")'
 #' 
 #' @param mri_path path to the volumetric T1 data.
-#' @param deface deface the input T1 data before analysis. Defaults to TRUE.
+#' @param deface deface the input T1 data before analysis. Defaults to FALSE.
 #' @param bet_fit fractional intensity threshold for bet brain extraction.
 #' Values should be between 0 and 1. Defaults to 0.5 with smaller values giving
 #' larger brain estimates.
 #' @export 
-segment_t1_fsl <- function(mri_path, deface = TRUE, bet_fit = 0.5) {
+segment_t1_fsl <- function(mri_path, deface = FALSE, bet_fit = 0.5) {
   dir_path <- dirname(mri_path)
   if (deface) {
     deface_path <- file.path(dir_path, "t1_deface")
